@@ -29,6 +29,7 @@ results <- list(
   comments = " ",
   has_bug_reports_url = "",
   license = "",
+  license_name = "",
   has_examples = "",
   has_maintainer = "",
   size_codebase = "",
@@ -42,11 +43,8 @@ results <- list(
   check = "",
   covr = "",
   dependencies = "",
-  dep_score = "",
   suggested_deps = "",
   rev_deps = "",
-  revdep_score = "",
-  license = "",
   author = "",
   host = "",
   github_data = "",
