@@ -5,6 +5,7 @@ globalVariables(c(
                   "Freq",
                   "Test_Coverage",
                   "Var1",
+                  "coverage_percent",
                   "comments",
                   "dependencies",
                   "description",
@@ -14,21 +15,39 @@ globalVariables(c(
                   "exported_function",
                   "exported_functions",
                   "functions",
+                  "function_body",
                   "function_calls",
+                  "function_type",
                   "has_bug_reports_url",
                   "imp_count",
                   "is_assignment",
                   "is_parameter",
+                  "join_key",
                   "link_count",
                   "matched",
                   "name",
                   "overall_risk_score",
                   "package",
                   "pkg_name",
-                  "pkg_version", 
+                  "pkg_version",
+                  "server",
                   "sug_count",
                   "suggested_function",
                   "targeted_package",
                   "type",
-                  "value"
+                  "value",
+                  "Date", 
+                  "Month", 
+                  "Nb_of_distinct_IPs",
+                  "Nb_of_downloads",
+                  "Year",
+                  "count",
+                  "cumulative_downloads",
+                  "day",
+                  "desc",
+                  "downloads",
+                  "month",
+                  "n_commits",
+                  "week_start",
+                  "year"
                   ))
