@@ -1,7 +1,18 @@
 test_that("install_package_local works correctly", {
-  # get system file
-  dp <- system.file("test-data", "test.package.0001_0.1.0.tar.gz", 
-                    package = "risk.assessr")
+  
+  # Copy test package to a temp file
+  dp_orig <- system.file("test-data", 
+                         "test.package.0001_0.1.0.tar.gz", 
+                         package = "risk.assessr")
+  dp <- tempfile(fileext = ".tar.gz")
+  file.copy(dp_orig, dp)
+  
+  # Defer cleanup of copied tarball
+  withr::defer(unlink(dp), envir = parent.frame())
+  
+  # Defer cleanup of unpacked source directory
+  withr::defer(unlink(pkg_source_path, recursive = TRUE, force = TRUE),
+               envir = parent.frame())
   
   suppressWarnings(pkg_source_path <-   
                      unpack_tarball(dp))
